==> ocular-0.4.4.tgz: package/templates/variables.scss.js <==
// Copyright (c) 2018 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

module.exports = () => `$primary: #00ADE6;
$secondary: #05E3D5;
$black: #041725;
$black-20: #213746;
$black-40: #5A666D;
$white: #EDEDED;
$white-40: #8D9BA3;

$font-family: 'source-sans-pro';

$footer-height: 13rem;
$topbar-height: 4rem;
$topbar-maxheight: 8rem;
$toc-width: 17rem;
$mobile: 576px;

$gradient-1: linear-gradient(to right, $primary 0%, $secondary 100%);
$gradient-2: linear-gradient(to bottom, $primary 0%, $secondary 100%);

`

==> ocular-0.6.1.tgz: package/templates/variables.scss.js <==
// Copyright (c) 2018 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

module.exports = () => `$primary: #00ADE6;
$secondary: #05E3D5;
$black: #041725;
$black-20: #213746;
$black-40: #5A666D;
$white: #EDEDED;
$white-40: #8D9BA3;

$font-family: 'Source Sans Pro';

$footer-height: 13rem;
$topbar-height: 4rem;
$topbar-maxheight: 8rem;
$toc-width: 17rem;
$mobile: 576px;

$gradient-1: linear-gradient(to right, $primary 0%, $secondary 100%);
$gradient-2: linear-gradient(to bottom, $primary 0%, $secondary 100%);
`
